@@ -4,10 +4,22 @@ package Alien::PortMidi;
 
 # ABSTRACT: Install the Mixxx fork of PortMidi
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use parent qw/ Alien::Base /;
 
+BEGIN {
+    # On *nix we can set RPATH to $ORIGIN so portmidi can find porttime
+    # in the same dir. Windows DLL search path does not offer similar.
+    # Explicitly loading porttime before portmidi obviates the need to
+    # worry about the Windows search path.
+    if ( $^O eq 'MSWin32' ) {
+        require DynaLoader;
+        DynaLoader::dl_load_file($_)
+          for grep { /porttime/ } __PACKAGE__->dynamic_libs;
+    }
+}
+
 
 
 
@@ -29,7 +41,7 @@ Alien::PortMidi - Install the Mixxx fork of PortMidi
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
